
import { Toaster } from "@/components/ui/toaster";
import { Toaster as Sonner } from "@/components/ui/sonner";
import { TooltipProvider } from "@/components/ui/tooltip";
import { QueryClient, QueryClientProvider } from "@tanstack/react-query";
import { BrowserRouter } from "react-router-dom";
import { AuthProvider } from "./contexts/AuthContext";
import { LanguageProvider } from "./contexts/LanguageContext";
import { ThemeProvider } from "./contexts/ThemeContext";
import { NetworkErrorBoundary } from "./components/NetworkErrorBoundary";
import { useState, useEffect } from 'react';
import LandingPage from "./components/LandingPage";

// Optimized QueryClient for Vercel
const queryClient = new QueryClient({
  defaultOptions: {
    queries: {
      retry: (failureCount, error: any) => {
        if (error?.response?.status >= 400 && error?.response?.status < 500) {
          return false;
        }
        return failureCount < 1; // Reduced retry attempts for Vercel
      },
      retryDelay: (attemptIndex) => Math.min(500 * 2 ** attemptIndex, 5000), // Faster retries
      staleTime: 5 * 60 * 1000, // 5 minutes
      gcTime: 10 * 60 * 1000, // 10 minutes
      refetchOnWindowFocus: false,
      refetchOnReconnect: true,
    },
  },
});

// Loading component for better UX
const LoadingSpinner = () => (
  <div className="flex items-center justify-center min-h-screen bg-gray-50">
    <div className="text-center p-8">
      <div className="w-24 h-24 mx-auto mb-4">
        <img 
          src="/lovable-uploads/3f6d339d-bb79-42ee-8a84-da19176ccca1.png" 
          alt="BlockPA Logo" 
          className="w-full h-full object-contain" 
        />
      </div>
      <div className="animate-spin rounded-full h-12 w-12 border-4 border-gray-200 border-t-blue-600 mx-auto mb-4"></div>
      <p className="text-blue-600 font-medium">Caricamento...</p>
    </div>
  </div>
);

// Simple component that just shows the landing page
const AppRoutes = () => {
  return (
    <AuthProvider>
      <LandingPage />
    </AuthProvider>
  );
};

function App() {
  const [isOnline, setIsOnline] = useState(navigator.onLine);
  const [appReady, setAppReady] = useState(false);

  useEffect(() => {
    const handleOnline = () => {
      setIsOnline(true);
      console.log('App is back online');
    };
    
    const handleOffline = () => {
      setIsOnline(false);
      console.log('App is offline');
    };

    window.addEventListener('online', handleOnline);
    window.addEventListener('offline', handleOffline);

    return () => {
      window.removeEventListener('online', handleOnline);
      window.removeEventListener('offline', handleOffline);
    };
  }, []);

  // Enhanced session management for Vercel
  useEffect(() => {
    const checkSessionHealth = () => {
      try {
        const token = localStorage.getItem('blockpa_token') || localStorage.getItem('token');
        const isLoggedIn = localStorage.getItem('blockpa_authenticated') === 'true' || localStorage.getItem('isLoggedIn') === 'true';
        
        if (token && isLoggedIn) {
          const lastRefresh = localStorage.getItem('lastSessionRefresh');
          const now = new Date().toISOString();
          
          if (!lastRefresh) {
            localStorage.setItem('lastSessionRefresh', now);
          }
          
          // Check if session is getting stale (24 hours)
          if (lastRefresh) {
            const lastRefreshTime = new Date(lastRefresh).getTime();
            const currentTime = new Date().getTime();
            const hoursSinceRefresh = (currentTime - lastRefreshTime) / (1000 * 60 * 60);
            
            if (hoursSinceRefresh > 24) {
              console.log('Session is stale, updating timestamp');
              localStorage.setItem('lastSessionRefresh', now);
            }
          }
        }
      } catch (error) {
        console.warn('Session health check failed:', error);
      }
    };

    // Initial session health check
    checkSessionHealth();
    
    // Periodic session health check
    const sessionHealthInterval = setInterval(checkSessionHealth, 30 * 60 * 1000); // Check every 30 minutes
    
    return () => clearInterval(sessionHealthInterval);
  }, []);

  // Faster app initialization
  useEffect(() => {
    const initApp = async () => {
      try {
        // Minimal initialization delay
        await new Promise(resolve => setTimeout(resolve, 10));
        setAppReady(true);
      } catch (error) {
        console.error('App initialization failed:', error);
        setAppReady(true); // Still show app even if init fails
      }
    };

    initApp();
  }, []);

  if (!isOnline) {
    return (
      <div className="flex items-center justify-center min-h-screen bg-gray-100">
        <div className="bg-white p-8 rounded-lg shadow-md max-w-md w-full text-center">
          <h2 className="text-xl font-bold text-red-600 mb-4">Connessione Internet non disponibile</h2>
          <p className="mb-4">Controlla la tua connessione e ricarica la pagina.</p>
          <button 
            onClick={() => window.location.reload()} 
            className="bg-blue-600 text-white px-4 py-2 rounded hover:bg-blue-700"
          >
            Riprova
          </button>
        </div>
      </div>
    );
  }

  if (!appReady) {
    return <LoadingSpinner />;
  }

  return (
    <NetworkErrorBoundary>
      <QueryClientProvider client={queryClient}>
        <TooltipProvider>
          <BrowserRouter>
            <LanguageProvider>
              <ThemeProvider>
                <Toaster />
                <Sonner />
                <AppRoutes />
              </ThemeProvider>
            </LanguageProvider>
          </BrowserRouter>
        </TooltipProvider>
      </QueryClientProvider>
    </NetworkErrorBoundary>
  );
}

export default App;
